package com.dhcc.finance.main.service;

import java.util.List;

import com.dhcc.common.model.CurrencyMeta;
import com.dhcc.common.model.response.RestfulResponse;
import com.dhcc.finance.main.domain.CwBdVouchtemp;
import com.dhcc.finance.main.model.CwBdVouchtempAdd;
import com.github.pagehelper.PageInfo;

/**
 * 功能描述：凭证模板配置接口
 * @author dml
 * @date 2019年3月27日 下午1:47:45
 * @修改日志：
 */
public interface CwBdVouchtempService {
	/**
	 * 功能描述：查询全部凭证模板配置
	 * @param pageNum
	 * @param pageSize
	 * @param navigatePages
	 * @return RestfulResponse<PageInfo<CwBdVouchtemp>,CurrencyMeta>
	 * @author dml
	 * @date 2019年3月27日 下午1:54:05
	 * @修改日志：
	 */
	RestfulResponse<PageInfo<CwBdVouchtemp>, CurrencyMeta> searchCwBdVouchtempAllData(int pageNum, int pageSize, int navigatePages,String nameLike
			,String Ismanual,String CODE);
	/**
	 * 功能描述：查询全部凭证模板配置(凭证类型为一的)
	 * @param pageNum
	 * @param pageSize
	 * @param navigatePages
	 * @return RestfulResponse<PageInfo<CwBdVouchtemp>,CurrencyMeta>
	 * @author lipeng
	 * @date 2019年7月25日 下午1:54:05
	 * @修改日志：
	 */
	RestfulResponse<PageInfo<CwBdVouchtemp>, CurrencyMeta> searchCwBdVouchtempAllDataForISMANUAL(int pageNum, int pageSize, int navigatePages);

	/**
	 * 功能描述：新增凭证模板配置
	 * @param CwBdVouchtempAdd
	 * @return RestfulResponse<Object,CurrencyMeta>
	 * @author dml
	 * @date 2019年3月27日 下午2:14:15
	 * @修改日志：
	 */
	RestfulResponse<Object, CurrencyMeta> addCwBdVouchtemp(CwBdVouchtempAdd cwBdVouchtempAdd);
	/**
	 * 功能描述：通过主键修改凭证模板配置
	 * @param cwBdVouchtemp
	 * @return RestfulResponse<Object,CurrencyMeta>
	 * @author dml
	 * @date 2019年3月27日 下午2:15:08
	 * @修改日志：
	 */
	RestfulResponse<Object, CurrencyMeta> updateCwBdVouchtempByPk(CwBdVouchtemp cwBdVouchtemp);
	/**
	 * 功能描述：逻辑删除凭证模板配置
	 * @param pkVouchtemp
	 * @return RestfulResponse<Object,CurrencyMeta>
	 * @author dml
	 * @date 2019年3月27日 下午2:16:06
	 * @修改日志：
	 */
	RestfulResponse<Object, CurrencyMeta> deleteCwBdVouchtempByPk(String pkVouchtemp);
	/**
	 * 功能描述:查询凭证模板所有信息
	 * @return RestfulResponse<List<CwBdVouchtemp>,CurrencyMeta>
	 *@author baiyc
	 *@date 2019年4月8日 下午7:44:59
	 *@修改日志:
	 */
	RestfulResponse<List<CwBdVouchtemp>, CurrencyMeta> searchCwBdVouchtemp();
	
}
